NLSL: confc.f90 Source File

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

confc.f90
Go to the documentation of this file.
1 c Version 1.4 1/1/95
2 c----------------------------------------------------------------------
3 c =========================
4 c subroutine CONFC
5 c =========================
6 c----------------------------------------------------------------------
7 subroutine confc( line )
8 c
9 use iterat
10 use stdio
11 c
12 implicit none
13 character*80 line
14 c
15 character*30 token
16 double precision fval
17 integer lth
18 c
19 logical ftoken
20 external ftoken
21 c
22 call gettkn(line,token,lth)
23 if (lth.eq.0) then
24 write (luttyo,1000)
25 end if
26 if ( ftoken(token,lth,fval) ) then
27 if (fval.lt.0.0d0 .or. fval.gt.1.0d0) then
28 write(luttyo,1002)
29 else
30 confid=fval
31 end if
32 else
33 write (luttyo,1003) token(:lth)
34 end if
35 return
36 c
37 c ##### Formats ##################################################
38 c
39 1000 format(' *** Confidence level missing ***')
40 1002 format(' *** Confidence level must be between 0 and 1 ***')
41 1003 format(' *** Illegal floating point value: ''',a,''' ***')
42 end
iterat
Definition: iterat.f90:11
confc
subroutine confc(line)
Definition: confc.f90:8
iterat::confid
double precision, save confid
Definition: iterat.f90:15
stdio
Definition: stdio.f90:26
gettkn
subroutine gettkn(line, token, lth)
Written for free-form input of parameters for slow-motional calculations. Returns a token consisting ...
Definition: strutl1.f90:75
stdio::luttyo
integer, parameter luttyo
Definition: stdio.f90:29